@@ -1,11 +1,15 @@
-# -*- mode:python; coding:utf-8; tab-width:4 -*-
+# -*- mode: python; coding: utf-8 -*-
 
-##-- WARNING: be ware no including here nothing about encoding: JSON, BSON, etc.
+from bson import objectid
 
 
 def any_to_marshable(value):
     if isinstance(value, str):
-        return unicode(value)
+        try:
+            return unicode(value)
+        except UnicodeDecodeError:
+            print "UnicodeDecodeError: '{0}'".format(value)
+            raise
 
     if isinstance(value, (unicode, int, bool, float, long)):
         return value
@@ -16,12 +20,18 @@ def any_to_marshable(value):
     if hasattr(value, 'to_marshable'):
         return value.to_marshable()
 
+    if hasattr(value, 'to_json'):
+        return value.to_json()
+
     if isinstance(value, (list, tuple)):
         return [any_to_marshable(x) for x in value]
 
     if isinstance(value, dict):
         return dict_to_marshable(value)
 
+    if isinstance(value, objectid.ObjectId):
+        return str(value)
+
     # last resort
     return class_to_marshable(value)
 
