@@ -190,6 +190,11 @@ Transceiver: Class.extend({
 	    promise.resolve();
 
 	    websocket.onclose = function(event) {
+		if (event.code == 403){
+		    log.error("Error on socket:", event.reason);
+		    return;
+		}
+
 		log.debug("Socket closed:", event);
 		if (! wise.no_reconnect)
 		    self._try_reconnect();
@@ -511,8 +516,9 @@ TransceiverFactory: Class.extend({
     },
 }),
 
+// FIXME: improve this parser (and test this)
 EndpointInfo: Class.extend({
-    init: function(endpoint, defaults) {
+    init: function(endpoint, defaults, oaendpoint) {
 	if (endpoint == undefined)
 	    endpoint = "";
 
@@ -532,17 +538,25 @@ EndpointInfo: Class.extend({
 	// web service locator
 	this.ws_name = "";
 	index = items.indexOf("-w");
-	if (index != -1)
+	if (index != -1) {
 	    this.ws_name = items[index + 1];
+	    items.splice(index, 2);
+	}
 
-	if (this.ws_name == "")
-	    this.ws_name = this._get_random_ws_name();
+	if (this.ws_name == "") {
+	    if (oaendpoint)
+		this.ws_name = this._get_random_ws_name();
+	    else
+		throw "Invalid endpoint, no WS especified";
+	}
 
 	// hostname
 	this.host = "";
 	index = items.indexOf("-h");
-	if (index != -1)
+	if (index != -1) {
 	    this.host = items[index + 1];
+	    items.splice(index, 2);
+	}
 
 	if (this.host == "") {
 	    if (! defaults || ! defaults.host)
@@ -553,14 +567,21 @@ EndpointInfo: Class.extend({
 	// port
 	this.port = "";
 	index = items.indexOf("-p");
-	if (index != -1)
+	if (index != -1) {
 	    this.port = items[index + 1];
+	    items.splice(index, 2);
+	}
 
 	if (this.port == "") {
 	    if (! defaults || ! defaults.port)
 		throw "Invalid endpoint, no port especified";
 	    this.port = defaults.port;
 	}
+
+	for (var i in items) {
+	    if (items[i])
+		throw "Invalid endpoint, unknown params: " + items;
+	}
     },
 
     _get_random_ws_name: function() {
@@ -740,6 +761,20 @@ Logger: Class.extend({
     },
 }),
 
+// Add a callback to be called when a communicator is created
+on_communicator_ready: function(callback) {
+    if (this._last_communicator) {
+	callback(this._last_communicator);
+	return;
+    }
+
+    if (this._waiting_for_init === undefined) {
+	this._waiting_for_init = [];
+    }
+
+    this._waiting_for_init.push(callback);
+},
+
 Communicator: Class.extend({
     init: function(args) {
 	this._host = args.host;
@@ -753,9 +788,9 @@ Communicator: Class.extend({
 	if (name in this._adapters)
 	    throw "AlreadyRegisteredException"
 
-	var transceiver = this._transceiverFactory.create_transceiver(
-	    new wise.EndpointInfo(endpoint, {host: this._host, port: this._port}))
-	    .then(bind(this, on_create_transceiver_response));
+	this._transceiverFactory.create_transceiver(
+	    new wise.EndpointInfo(endpoint, {host: this._host, port: this._port}, true)
+	).then(bind(this, on_create_transceiver_response))
 
 	var promise = new wise.Promise();
 	function on_create_transceiver_response(transceiver) {
@@ -831,11 +866,18 @@ Communicator: Class.extend({
 
     ready: function() {
 	// notify to others that this part is ready
-	_("wise.ready called");
 	var div = document.createElement('div');
 	div.id = 'wiseReady';
 	var body = document.querySelector('body');
 	body.appendChild(div);
+
+	wise._last_communicator = this;
+	if (wise._waiting_for_init !== undefined) {
+	    for (var i in wise._waiting_for_init) {
+		wise._waiting_for_init[i](this);
+	    }
+	    wise._waiting_for_init.length = 0;
+	}
     },
 }),
 
@@ -868,6 +910,7 @@ initialize: function(host, port) {
 
 	// finish intialization
 	promise.resolve(ic);
+	ic.ready()
     }
 
     return promise;
@@ -978,6 +1021,7 @@ Promise: Class.extend({
 	    this._PRP(promise, x);
 	} catch (e) {
 	    console.error("Exception in promise callback: " + e.stack);
+	    console.error(e);
 	    promise.reject(e);
 	}
     },
